==> dde-calendar_5.9.5.orig.tar.xz: dde-calendar-5.9.5/translations/dde-calendar-service_pt.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="pt">
<context>
    <name>DAccountDataBase</name>
    <message>
        <source>Work</source>
        <translation>Trabalho</translation>
    </message>
    <message>
        <source>Life</source>
        <translation>Vida</translation>
    </message>
    <message>
        <source>Other</source>
        <translation>Outro</translation>
    </message>
</context>
<context>
    <name>DAlarmManager</name>
    <message>
        <source>Close</source>
        <comment>button</comment>
        <translation>Fechar</translation>
    </message>
    <message>
        <source>One day before start</source>
        <translation>Um dia antes do início</translation>
    </message>
    <message>
        <source>Remind me tomorrow</source>
        <translation>Lembra-me amanhã</translation>
    </message>
    <message>
        <source>Remind me later</source>
        <translation>Lembrar-me mais tarde</translation>
    </message>
    <message>
        <source>15 mins later</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>1 hour later</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>4 hours later</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Tomorrow</source>
        <translation>Amanhã</translation>
    </message>
    <message>
        <source>Schedule Reminder</source>
        <translation>Agendar lembrete</translation>
    </message>
    <message>
        <source>%1 to %2</source>
        <translation>%1 até %2</translation>
    </message>
    <message>
        <source>Today</source>
        <translation>Hoje</translation>
    </message>
</context>
<context>
    <name>JobRemindManager</name>
    <message>
        <source>One day before start</source>
        <translation type="vanished">Um dia antes do início</translation>
    </message>
    <message>
        <source>Close</source>
        <comment>button</comment>
        <translation type="vanished">Fechar</translation>
    </message>
    <message>
        <source>Remind me tomorrow</source>
        <translation type="vanished">Lembra-me amanhã</translation>
    </message>
    <message>
        <source>Remind me later</source>
        <translation type="vanished">Lembrar-me mais tarde</translation>
    </message>
    <message>
        <source>Schedule Reminder</source>
        <translation type="vanished">Agendar lembrete</translation>
    </message>
    <message>
        <source>%1 to %2</source>
        <translation type="vanished">%1 até %2</translation>
    </message>
    <message>
        <source>Today</source>
        <translation type="vanished">Hoje</translation>
    </message>
    <message>
        <source>Tomorrow</source>
        <translation type="vanished">Amanhã</translation>
    </message>
</context>
</TS>

==> dde-calendar_5.9.14.orig.tar.xz: dde-calendar-5.9.14/translations/dde-calendar-service_pt.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="pt">
<context>
    <name>DAccountDataBase</name>
    <message>
        <source>Work</source>
        <translation>Trabalho</translation>
    </message>
    <message>
        <source>Life</source>
        <translation>Vida</translation>
    </message>
    <message>
        <source>Other</source>
        <translation>Outro</translation>
    </message>
</context>
<context>
    <name>DAlarmManager</name>
    <message>
        <source>Close</source>
        <comment>button</comment>
        <translation>Fechar</translation>
    </message>
    <message>
        <source>One day before start</source>
        <translation>Um dia antes do início</translation>
    </message>
    <message>
        <source>Remind me tomorrow</source>
        <translation>Lembra-me amanhã</translation>
    </message>
    <message>
        <source>Remind me later</source>
        <translation>Lembrar-me mais tarde</translation>
    </message>
    <message>
        <source>15 mins later</source>
        <translation>15 mins depois</translation>
    </message>
    <message>
        <source>1 hour later</source>
        <translation>1 hora depois</translation>
    </message>
    <message>
        <source>4 hours later</source>
        <translation>4 horas depois</translation>
    </message>
    <message>
        <source>Tomorrow</source>
        <translation>Amanhã</translation>
    </message>
    <message>
        <source>Schedule Reminder</source>
        <translation>Agendar lembrete</translation>
    </message>
    <message>
        <source>%1 to %2</source>
        <translation>%1 até %2</translation>
    </message>
    <message>
        <source>Today</source>
        <translation>Hoje</translation>
    </message>
</context>
<context>
    <name>Return</name>
    <message>
        <source>Today</source>
        <comment>Return</comment>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Return Today</name>
    <message>
        <source>Today</source>
        <comment>Return Today</comment>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>today</name>
    <message>
        <source>Today</source>
        <comment>Today</comment>
        <translation type="unfinished"/>
    </message>
</context>
</TS>
